@@ -91,16 +91,16 @@ class LiveReloadHandler(websocket.WebSocketHandler):
 
     def watch_tasks(self):
 
-        path = Task.watch()
-        if path:
+        changes = Task.watch()
+        if changes:
             send_notify(
                 'Reload %s waiters'
                 '\nChanged %s'
-                % (len(LiveReloadHandler.waiters), path)
+                % (len(LiveReloadHandler.waiters), changes)
             )
             msg = {
                 'command': 'reload',
-                'path': path,
+                'path': '*',
                 'liveCSS': True
             }
             for waiter in LiveReloadHandler.waiters:
@@ -148,10 +148,29 @@ class LiveReloadHandler(websocket.WebSocketHandler):
 class IndexHandler(tornado.web.StaticFileHandler):
     def get(self, path):
         if path.endswith('/'):
+            root = path
+
             path = path + 'index.html'
+            if not os.path.exists(path):
+                self.create_index(root)
+                return
 
         super(IndexHandler, self).get(path)
 
+    def create_index(self, root):
+        files = os.listdir(root)
+        self.write('<ul>')
+        for f in files:
+            path = os.path.join(root, f)
+            self.write('<li>')
+            if os.path.isdir(path):
+                self.write('<a href="%s/">%s</a>' % (f, f))
+            else:
+                self.write('<a href="%s">%s</a>' % (f, f))
+            self.write('</li>')
+
+        self.write('</ul>')
+
 
 handlers = [
     (r'/livereload', LiveReloadHandler),
@@ -178,6 +197,8 @@ def main():
     tornado.options.parse_command_line()
     app = tornado.web.Application(handlers=handlers)
     app.listen(35729)
+    #: task watch initialize
+    Task.watch()
     print('Start service at  127.0.0.1:35729')
     tornado.ioloop.IOLoop.instance().start()
 
